FlowTrigger class
Constructors
- FlowTrigger({required String name, required TriggerCondition condition, required FlowPipeline pipeline})
Properties
- condition → TriggerCondition
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
- pipeline → FlowPipeline
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
checkAndRun(
FlowContext context) → Future< void> -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited